@@ -18,7 +18,7 @@ typedef struct board {
 
 Board board;
 
-void update_board(void);
-void flip_board(void);
-void set_flip(gboolean f);
-GtkWidget * init_board(void);
+GtkWidget * gnomechess_board_new(void);
+void gnomechess_board_set_flip(gboolean f);
+void gnomechess_board_flip(void);
+void gnomechess_board_update(void);
\ No newline at end of file
