@@ -1,4 +1,20 @@
-/* engine.c */
+/* 
+ * Copyright (C) 1999 Robert Wilhelm
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
+ */
 
 #include "gnome_chess.h"
 #include <ctype.h>
@@ -7,7 +23,6 @@
 #include <signal.h>
 
 #include "makros.h"
-#include "portab.h"
 #include "child.h"
 #include "cho1.h"
 #include "pro.h"
@@ -21,6 +36,8 @@ struct engine * engine_new(char *cmd, char **arg)
   struct engine *e;
 
   e = malloc( sizeof(struct engine));
+  e->childpid = 0;
+
   e->notation = COORD;
   e->menudata = malloc(sizeof(struct engine_menu));
   e->menudata->menu_init = NULL;
@@ -40,7 +57,9 @@ struct engine * engine_new(char *cmd, char **arg)
   e->menudata->menu_analyze_cb = NULL;
 
   e->data = NULL;
-  start_child(cmd, arg, &e->read_from, &e->write_to, &e->childpid);
+
+  if (cmd != NULL)
+  	start_child(cmd, arg, &e->read_from, &e->write_to, &e->childpid);
 
   engines = g_slist_append(engines,e);
 
@@ -53,20 +72,20 @@ void engine_write(struct engine *e, char *format,...)
 
   va_list ap;
   va_start(ap,format);
-  vfprintf(file,format,ap);
-  if (debug)
-    vfprintf(stderr,format,ap);  
+  if (file)
+    vfprintf(file,format,ap);
+  debug_print(DEBUG_VERBOSE,format,ap);  
   va_end(ap);
 }
 
-static void position_to_engine(void)
+static void position_to_engine(struct engine *e)
 {
   int i;
   char s[10];
   char *p;
 
-  engine_write(first_chess_programm,"edit\n");
-  engine_write(first_chess_programm,"#\n");
+  engine_write(e,"edit\n");
+  engine_write(e,"#\n");
 
   for (i=A1; i<= H8;i++)
     {
@@ -86,10 +105,10 @@ static void position_to_engine(void)
       *p++   = i / 10 + 47 ;              /*  1 - 8       */
       *p=0;
       printf("%s\n",s);  
-      engine_write(first_chess_programm,"%s\n",s);  
+      engine_write(e,"%s\n",s);  
     }
 
-  engine_write(first_chess_programm,"c\n");  
+  engine_write(e,"c\n");  
   
   for (i=A1; i<= H8;i++)
     {
@@ -109,18 +128,20 @@ static void position_to_engine(void)
       *p++   = i / 10 + 47 ;              /*  1 - 8       */
       *p=0;
       printf("%s\n",s);  
-      engine_write(first_chess_programm,"%s\n",s);  
+      engine_write(e,"%s\n",s);  
     }
 
-  engine_write(first_chess_programm,".\n");
+  engine_write(e,".\n");
 }
 
 void engine_write_move(int from, int to) {
   char s[100];
   char *str = NULL;
 
+  if (first_chess_programm == NULL) return;
+
   if (gnomechess_movelist_currply(board.movelist) != gnomechess_movelist_maxply(board.movelist))
-       position_to_engine();
+       position_to_engine(first_chess_programm);
 
   if (first_chess_programm->notation) {
 	move_to_ascii(s,from,to);
