@@ -51,23 +51,19 @@ struct engine {
 	int notation;
 	struct engine_menu *menudata;
 	void *data;
+        gint input_callback;
 };
 
 extern struct engine *first_chess_programm;
 
 struct engine * engine_new(char *cmd, char **arg);
-int engine_destroy( struct engine *e);
-void engine_destroy_all(void);
-
 #ifdef __GNUC__
 void engine_write(struct engine *, char *format,...) __attribute__ (( __format__(printf,2,3)));
 #else
 void engine_write(struct *engine, char *format,...); 
 #endif
-
 void engine_write_move(int from, int to);
-
-/* Now some prototypes for the various engines */
-void engine_local_cb( gpointer data, gint source, GdkInputCondition condition);
+int engine_destroy( struct engine *e);
+void engine_destroy_all(void);
 
 #endif
