@@ -22,7 +22,6 @@
 #include <stdarg.h>
 #include <signal.h>
 
-#include "portab.h"
 #include "cho1.h"
 #include "pro.h"
 #include "position.h"
@@ -136,7 +135,6 @@ char *engine_ics_get_pass(struct engine *e) {
   return ei->pass;
 }
 
-
 void engine_ics_set_pass(struct engine *e, gchar *pass) {
   struct engine_ics *ei;
 
@@ -146,7 +144,6 @@ void engine_ics_set_pass(struct engine *e, gchar *pass) {
   ei->pass = pass;
 }
 
-
 gboolean engine_ics_is_loggedin(struct engine *e) {
   struct engine_ics *ei;
 
@@ -197,12 +194,12 @@ static void engine_ics_start_cb (GtkWidget *widget, void *data) {
 }
 
 static void engine_ics_previous_cb (GtkWidget *widget, void *data) {
-  gnomechess_movelist_move_forward(board.movelist);
+  gnomechess_movelist_move_back(board.movelist);
   gnomechess_board_update();
 }
 
 static void engine_ics_next_cb (GtkWidget *widget, void *data) {
-  gnomechess_movelist_move_back(board.movelist);
+  gnomechess_movelist_move_forward(board.movelist);
   gnomechess_board_update();
 }
 
@@ -282,7 +279,7 @@ void engine_ics_update_board (char *boardstring) {
 	char *temp;
 	char b[65];
 	char m[10];
-	int state, rank=0, rel=0, game=0, flip=0, num=0, ply=0, colour=0;
+	int state, rank=0, rel=0, game=0, setgame=0, flip=0, num=0, ply=0, maxply=0, colour=0;
 	int from,to,piece;
 	enum {START=0, BOARD=1, COLOUR=2, DOUBLE=3, WCS=4, WCL=5, BCS=6, BCL=7, 
 			MOVE=8, GAME=9,	WNAME=10, BNAME=11, RELATION=12, TIME=13, INC=14,
@@ -292,8 +289,7 @@ void engine_ics_update_board (char *boardstring) {
 	state = START;
 	temp = boardstring;
 	strcpy(b, "");
-	if (debug)
-		printf("***:%s\n",boardstring);
+	debug_print(DEBUG_NORMAL,"%s\n",boardstring);
 	temp = strtok(temp, " ");
 	while (temp) {
 		switch (state) {
@@ -320,9 +316,9 @@ void engine_ics_update_board (char *boardstring) {
 				break;
 			case COLOUR:
 				if (!strcmp(temp, "W"))
-					colour = WMOVE;
+					colour = WHITE;
 				else
-					colour  = BMOVE;
+					colour  = BLACK;
 				state++;
 				break;
 			case GAME:
@@ -382,7 +378,7 @@ void engine_ics_update_board (char *boardstring) {
 	if (rel == -3 || rel == -2 || rel == 2) {
 		gnomechess_timer_stop(board.whitetime);
 		gnomechess_timer_stop(board.blacktime);
-	} else if (colour == WMOVE) {
+	} else if (colour == WHITE) {
 		gnomechess_timer_stop(board.blacktime);
 		gnomechess_timer_start(board.whitetime);
 	} else {
@@ -393,7 +389,7 @@ void engine_ics_update_board (char *boardstring) {
 	/* Figure out what ply this is */
 	if (!strcmp(m, "none")) {
 		ply =  0;
-	} else if (colour == WMOVE) {
+	} else if (colour == WHITE) {
 		ply = num*2-2;
 	} else {
 		ply = num*2-1;
@@ -401,24 +397,33 @@ void engine_ics_update_board (char *boardstring) {
 
 	/* Setup the board and figure out the move if there */
 	/* was no dnd update or this is a different game */
-	if (gnomechess_movelist_maxply(board.movelist)<ply ||
-			game != engine_ics_get_game(first_chess_programm)){
-                gnomechess_sound_enginemove();
-		engine_ics_set_board (b);
-		if (strcmp(m, "none")) {
+	maxply = gnomechess_movelist_maxply(board.movelist);
+	setgame = engine_ics_get_game(first_chess_programm);
+	if (maxply < ply || game != setgame){
+		if (strcmp(m, "none")) 
 			ascii_to_move(m,&from,&to);
+
+		if (ply-maxply == 1 && strcmp(m, "none") && game == setgame) {
+			gnomechess_position_move(currPositionPtr, from, to);
+		} else {
+			gnomechess_position_set_initial(currPositionPtr);
+			engine_ics_set_board (b);
+		}
+                gnomechess_sound_enginemove();
+
+		if (strcmp(m, "none")) {
 			piece = currPositionPtr->square[to];
-			if (debug)
-				printf("move detected: %s %d %d %d %d\n",m,currPositionPtr->tomove,piece,from,to);
+			debug_print(DEBUG_NORMAL,"Move detected: %s %d %d %d\n",
+						m,piece,from,to);
 			gnomechess_movelist_add(board.movelist, piece,from,to);
 		}
 	}
 	currPositionPtr->tomove = colour;
 
 	/* Clear the movelist if this is a different game */
-	if (game != engine_ics_get_game(first_chess_programm)) {
-		gnomechess_position_set_initial(currPositionPtr);
-		gnomechess_movelist_clear_initial(board.movelist, currPositionPtr);
+	if (game != setgame) {
+		gnomechess_movelist_clear_initial(board.movelist, ply, currPositionPtr);
+		debug_print(DEBUG_NORMAL,"Initializing at ply: %d\n", ply);
 		gnomechess_movelist_set_result(board.movelist, "");
 		engine_ics_set_game(first_chess_programm, game);
 	}
