@@ -18,28 +18,13 @@
 
 #include "../config.h"
 #include "gnome_chess.h"
-#include "portab.h"
 #include "makros.h"
 #include "position.h"
 #include "pro.h"
 #include "pgn.h"
  
-#ifdef CHESS_ENGINE_CRAFTY
-#define     FIRST_CHESS_PROGRAMM CHESS_ENGINE_CRAFTY
-#define     FIRST_CHESS_PROGRAMM_ARG "xboard"
-#else
-#ifdef CHESS_ENGINE_GNUCHESS
-#define     FIRST_CHESS_PROGRAMM CHESS_ENGINE_GNUCHESS
-#define     FIRST_CHESS_PROGRAMM_ARG NULL
-#endif
-#endif
-#define TELNET_PROGRAM telnet
-
 struct engine *first_chess_programm;
 
-/* The debugging level */
-int debug = 0;
-
 GtkWidget *app;
 static gint *ics = 0;
 static char *icshost = NULL;
@@ -73,49 +58,58 @@ static const struct poptOption gnome_chess_popt_options [] = {
 	{ NULL, '\0', 0, NULL, 0 }
 };
 
-int main(int argc,char *argv[])
-{
-     GtkWidget *box;
+int main(int argc,char *argv[]) {
+	GtkWidget *box;
 
-     bindtextdomain (PACKAGE, GNOMELOCALEDIR);
-     textdomain (PACKAGE);
+	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+	textdomain (PACKAGE);
 
-     gnome_init_with_popt_table ("Gnome Chess", VERSION, argc, argv, gnome_chess_popt_options,0, &ctx);
+	gnome_init_with_popt_table ("Gnome Chess", VERSION, 
+			argc, argv, gnome_chess_popt_options,0, &ctx);
 
-	 currPositionPtr = gnomechess_position_new_initial();
+	/* Initialize the position and build a new board */
+	currPositionPtr = gnomechess_position_new_initial();
+	box = gnomechess_board_new();
 
-     //pgn_test(); 
+	/* Initialize the preferences */
+	gnomechess_prefs_init();
 
-     app = gnome_app_new ("gnome-chess", _("Gnome Chess"));
+	/* Build the app framework */
+	app = gnome_app_new ("gnome-chess", _("Gnome Chess"));
+	create_menus();
+	gnome_app_set_contents ( GNOME_APP (app), box);
+	gtk_widget_show(box);
+	gtk_widget_show (app);
 
-     create_menus();
+	first_chess_programm = NULL;
+	/* Check to see if we got command line args for an engine */
+	if (ics) {
+ 		first_chess_programm = engine_ics_new(icshost, icsuser, icspass, icsport, icstelnetprogram);
+	} else if (fcp) {
+		first_chess_programm = engine_local_new(fcp,NULL);
+	} else {
+		gchar *cmd;
+		cmd = gnome_is_program_in_path("crafty");
+		if (cmd)
+			first_chess_programm = engine_local_new(cmd,"xboard");
+	  	else {
+			cmd = gnome_is_program_in_path("gnuchessx");
+			if (cmd)
+				first_chess_programm = engine_local_new(cmd,NULL);
+		}
+	}
 
-     box = gnomechess_board_new();
-     gnome_app_set_contents ( GNOME_APP (app), box);
+	/* if no valid engine so far was found, we use a null engine. */
+	if (first_chess_programm == NULL)
+		first_chess_programm = engine_null_new(NULL,NULL);
 
-     gtk_widget_show(box);
-     gtk_widget_show (app);
+	/* Check to see if we got command line args for any pgn files */
+	startup_files = poptGetArgs (ctx);
+	if (startup_files) 
+		pgn_open(*startup_files);
+	poptFreeContext (ctx);
 
-     gnomechess_prefs_init();
-
-     if (ics) {
-       first_chess_programm = engine_ics_new(icshost, icsuser, icspass, icsport, icstelnetprogram);
-     } else if (fcp) {
-       first_chess_programm = engine_local_new(fcp,NULL);
-     } else {
-       first_chess_programm = engine_local_new(FIRST_CHESS_PROGRAMM,FIRST_CHESS_PROGRAMM_ARG);
-	 }
-
-     startup_files = poptGetArgs (ctx);
-     if (startup_files) 
-       pgn_open(*startup_files);
-     
-     poptFreeContext (ctx);
-
-
-     gtk_main ();
-
-
-     return 0;
+	gtk_main ();
+	return 0;
 }
 
