@@ -18,7 +18,6 @@
 
 #include <glib.h>
 
-#include "portab.h"
 #include "makros.h"
 #include "position.h"
 #include "pro.h"
@@ -28,54 +27,54 @@ static const int jump[]={ 8, 12,19, 21,-8,-12,-19,-21,
                    9, 11, 1, 10,-1,  1, 10, -1,
                   -9,-11, 1,-10,-1     };
 
-static BYTE *index,*sindex;
+static gchar *index,*sindex;
 
-static void sdouble(WORD af,WORD a,WORD b);
-static void wdouble(WORD af,WORD a,WORD b);
-static void neuer_zug(WORD von,WORD nach);
-static void neuer_szug(WORD von,WORD nach);
+static void sdouble(gshort af,gshort a,gshort b);
+static void wdouble(gshort af,gshort a,gshort b);
+static void neuer_zug(gshort von,gshort nach);
+static void neuer_szug(gshort von,gshort nach);
 static void s_ro_l(void);
 static void s_ro_k(void);
 static void w_ro_k(void);
 static void w_ro_l(void);
 
-static void wpawn2(WORD af);
-static void wpawn3(WORD af);
-static void wpawn5(WORD af);
-static void wpawn7(WORD af);
-static void wb_um2(WORD af,WORD ef);
-static void wknight(WORD af);
-static void wbishop(WORD af);
-static void wrook(WORD af);
-static void wqueen(WORD af);
-static void wking(WORD af);
-static void wkingro(WORD af);
+static void wpawn2(gshort af);
+static void wpawn3(gshort af);
+static void wpawn5(gshort af);
+static void wpawn7(gshort af);
+static void wb_um2(gshort af,gshort ef);
+static void wknight(gshort af);
+static void wbishop(gshort af);
+static void wrook(gshort af);
+static void wqueen(gshort af);
+static void wking(gshort af);
+static void wkingro(gshort af);
 
-static void bpawn7(WORD af);
-static void bpawn6(WORD af);
-static void bpawn4(WORD af);
-static void bpawn2(WORD af);
-static void sb_um2(WORD af,WORD ef);
-static void sknight(WORD af);
-static void sbishop(WORD af);
-static void srook(WORD af);
-static void squeen(WORD af);
-static void skingro(WORD af);
-static void sking(WORD af);
+static void bpawn7(gshort af);
+static void bpawn6(gshort af);
+static void bpawn4(gshort af);
+static void bpawn2(gshort af);
+static void sb_um2(gshort af,gshort ef);
+static void sknight(gshort af);
+static void sbishop(gshort af);
+static void srook(gshort af);
+static void squeen(gshort af);
+static void skingro(gshort af);
+static void sking(gshort af);
 
 
 
-static void inline neuer_zug(WORD von,WORD nach)
+static void inline neuer_zug(gshort von,gshort nach)
 {
 
-   *   index          = (BYTE) von;
-   * ( index + 1 )    = (BYTE) nach;
+   *   index          = (gchar) von;
+   * ( index + 1 )    = (gchar) nach;
        index         += 2;
 }
 
-static void wpawn2(WORD af)      
+static void wpawn2(gshort af)      
 {
-   register WORD ef;
+   register gshort ef;
 
     ef = af + 10;    
     if (currPositionPtr->square[ef] == EMPTY ) {
@@ -89,9 +88,9 @@ static void wpawn2(WORD af)
     if (BPIECE(currPositionPtr->square[af +11 ])) neuer_szug(af,af+11);
 }
 
-static void wpawn3(WORD af)  
+static void wpawn3(gshort af)  
 {
-   register WORD ef;
+   register gshort ef;
 
      ef = af + 10;
      if ( currPositionPtr->square[ef] == EMPTY ) neuer_zug(af,ef);
@@ -100,7 +99,7 @@ static void wpawn3(WORD af)
      if ( BPIECE( currPositionPtr->square[af +11 ] ) ) neuer_szug(af, af + 11 );
 }
 
-static void wpawn5(WORD af)   
+static void wpawn5(gshort af)   
 {
 
    wpawn3(af);
@@ -112,9 +111,9 @@ static void wpawn5(WORD af)
      neuer_szug(af,af+11);
 }
 
-static void  wpawn7(WORD af)
+static void  wpawn7(gshort af)
 {
-register WORD ef;
+register gshort ef;
 
    ef = af + 10;
    if (currPositionPtr->square[ef] == EMPTY ) wb_um2(af,ef);
@@ -123,18 +122,18 @@ register WORD ef;
    if (BPIECE( currPositionPtr->square[af +11] )) wb_um2 (af , af +11);
 
 }
-static void wb_um2(WORD af,WORD ef)
+static void wb_um2(gshort af,gshort ef)
 {
-register WORD b,i;
+register gshort b,i;
 
         for (i=2;i<6;i++) {
                 b = 128 + 8 * i + ef - A8;
                 neuer_szug(af,b);
         }
 }
-static void wknight(WORD af)
+static void wknight(gshort af)
 {
-   register WORD a,fi,bb;
+   register gshort a,fi,bb;
 
    for (a = 0 ; a < 8;a++) {
       bb=af+jump[a];
@@ -149,34 +148,34 @@ static void wknight(WORD af)
    }
 }
 
-static void wbishop(WORD af)
+static void wbishop(gshort af)
 {
-   WORD a = 8,
+   gshort a = 8,
         b = 12;
 
    wdouble(af,a,b);
 }
 
-static void wrook(WORD af)
+static void wrook(gshort af)
 {
-   WORD a = 12,
+   gshort a = 12,
         b = 16;
 
    wdouble(af,a,b);
 }
 
-static void wqueen(WORD af)
+static void wqueen(gshort af)
 {
-   WORD a = 8,
+   gshort a = 8,
         b = 16;
 
    wdouble(af,a,b);
 }
 
-static void wking(WORD af)
+static void wking(gshort af)
 {
-register WORD a;
-register WORD fi,bb;
+register gshort a;
+register gshort fi,bb;
 
    for (a = 8; a < 16 ; a++) {
       bb=af+jump[a];
@@ -191,10 +190,10 @@ register WORD fi,bb;
    }
 }
 
-static void wkingro(WORD af)  
+static void wkingro(gshort af)  
 {
-register WORD a;
-register WORD fi,bb;
+register gshort a;
+register gshort fi,bb;
 
    for (a = 8; a < 16 ; a++) {
       bb=af+jump[a];
@@ -228,9 +227,9 @@ static void w_ro_l(void)
       currPositionPtr->square[A1] == WR) 
     neuer_zug(E1,C1);
 }
-static void wdouble(WORD af,WORD a,WORD b)   
+static void wdouble(gshort af,gshort a,gshort b)   
 {
-        WORD jp,
+        gshort jp,
              ef = af,
              fi;
 
@@ -251,9 +250,9 @@ static void wdouble(WORD af,WORD a,WORD b)
         }
 }
 
-static void bpawn7(WORD af)      
+static void bpawn7(gshort af)      
 {
-   register WORD ef;
+   register gshort ef;
 
     ef = af - 10;                
     if (currPositionPtr->square[ef] == EMPTY ) {
@@ -269,9 +268,9 @@ static void bpawn7(WORD af)
     if (WPIECE(currPositionPtr->square[af -11 ])) neuer_szug(af,af-11);
 }
 
-static void bpawn6(WORD af)                
+static void bpawn6(gshort af)                
 {
-   register WORD ef;
+   register gshort ef;
 
      ef = af - 10;
      if ( currPositionPtr->square[ef] == EMPTY ) neuer_zug(af,ef);
@@ -280,7 +279,7 @@ static void bpawn6(WORD af)
      if ( WPIECE( currPositionPtr->square[af -11 ] ) ) neuer_szug(af, af - 11 );
 }
 
-static void bpawn4(WORD af)         
+static void bpawn4(gshort af)         
 {
    bpawn6(af);
 
@@ -290,9 +289,9 @@ static void bpawn4(WORD af)
      neuer_szug( af, af-9);
 }
 
-static void  bpawn2(WORD af)  
+static void  bpawn2(gshort af)  
 {
-register WORD ef;
+register gshort ef;
 
    ef = af - 10;
    if (currPositionPtr->square[ef] == EMPTY ) sb_um2(af,ef);
@@ -302,18 +301,18 @@ register WORD ef;
    if (WPIECE( currPositionPtr->square[af -11] )) sb_um2 (af , af -11);
 
 }
-static void sb_um2(WORD af,WORD ef)    
+static void sb_um2(gshort af,gshort ef)    
 {
-register WORD b,i;
+register gshort b,i;
  for (i=2;i<6;i++)
    {
      b = 128 + 8 * i + ef - A1;
      neuer_szug(af,b);
    }
 }
-static void sknight(WORD af)
+static void sknight(gshort af)
 {
-   register WORD a,fi,bb;
+   register gshort a,fi,bb;
 
    for (a = 0 ; a < 8;a++) {
       bb=af+jump[a];
@@ -328,34 +327,34 @@ static void sknight(WORD af)
    }
 }
 
-static void sbishop(WORD af)
+static void sbishop(gshort af)
 {
-   WORD a=8,
+   gshort a=8,
         b=12;
 
    sdouble(af,a,b);
 }
 
-static void srook(WORD af)
+static void srook(gshort af)
 {
-   WORD a = 12,
+   gshort a = 12,
         b = 16;
 
    sdouble(af,a,b);
 }
 
-static void squeen(WORD af)
+static void squeen(gshort af)
 {
-   WORD a=8,
+   gshort a=8,
         b=16;
 
    sdouble(af,a,b);
 }
 
-static void sking(WORD af)
+static void sking(gshort af)
 {
-register WORD a;
-register WORD fi,bb;
+register gshort a;
+register gshort fi,bb;
 
    for (a = 8; a < 16 ; a++) {
       bb=af+jump[a];
@@ -370,10 +369,10 @@ register WORD fi,bb;
    }
 }
 
-static void skingro(WORD af)     
+static void skingro(gshort af)     
 {
-register WORD a;
-register WORD fi,bb;
+register gshort a;
+register gshort fi,bb;
 
    for (a = 8; a < 16 ; a++) {
       bb=af+jump[a];
@@ -408,9 +407,9 @@ static void s_ro_l(void)
       currPositionPtr->square[A8] == BR) 
     neuer_zug(E8,C8);
 }
-static void sdouble(WORD af,WORD a,WORD b)  
+static void sdouble(gshort af,gshort a,gshort b)  
 {
-        WORD jp,
+        gshort jp,
              ef = af,
              fi;
 
@@ -432,16 +431,16 @@ static void sdouble(WORD af,WORD a,WORD b)
         }
 }
 
-static void neuer_szug(WORD von,WORD nach)  
+static void neuer_szug(gshort von,gshort nach)  
 {
                sindex       -= 2;
-            *  sindex        = (BYTE) von;
-            * (sindex + 1 )  = (BYTE) nach;
+            *  sindex        = (gchar) von;
+            * (sindex + 1 )  = (gchar) nach;
 }
 
-static int movgen_white(BYTE **index0,WORD *anz_s,WORD *anz_n)
+static int movgen_white(gchar **index0,gshort *anz_s,gshort *anz_n)
 {
-   register WORD af,figur;
+   register gshort af,figur;
 
    index = sindex = *index0;
 
@@ -552,8 +551,8 @@ static int movgen_white(BYTE **index0,WORD *anz_s,WORD *anz_n)
             }
          }
 
-      *anz_n = (WORD) (( index  - *index0) / 2) ;
-      *anz_s = (WORD) (( *index0 - sindex) / 2 );
+      *anz_n = (gshort) (( index  - *index0) / 2) ;
+      *anz_s = (gshort) (( *index0 - sindex) / 2 );
 
       af = *anz_n + *anz_s ;
       *index0 = sindex;
@@ -561,9 +560,9 @@ static int movgen_white(BYTE **index0,WORD *anz_s,WORD *anz_n)
       return af;
 }
 
-static int movgen_black(BYTE **index0,WORD *anz_s,WORD *anz_n)
+static int movgen_black(gchar **index0,gshort *anz_s,gshort *anz_n)
 {
-   register WORD af,figur;
+   register gshort af,figur;
 
    index = sindex = *index0;
 
@@ -672,8 +671,8 @@ static int movgen_black(BYTE **index0,WORD *anz_s,WORD *anz_n)
             }
       }
 
-      *anz_n = (WORD) (( index  - *index0) / 2) ;
-      *anz_s = (WORD) (( *index0 - sindex) / 2 );
+      *anz_n = (gshort) (( index  - *index0) / 2) ;
+      *anz_s = (gshort) (( *index0 - sindex) / 2 );
      
       af = *anz_n + *anz_s ;
       *index0 = sindex;
@@ -682,12 +681,12 @@ static int movgen_black(BYTE **index0,WORD *anz_s,WORD *anz_n)
 }
 
 
-int  move_generator(BYTE **index0,WORD *anz_s,WORD *anz_n)
+int  move_generator(gchar **index0,gshort *anz_s,gshort *anz_n)
 {
 
-	if (currPositionPtr->tomove == WMOVE ) 
+	if (currPositionPtr->tomove == WHITE ) 
 		return movgen_white(index0,anz_s,anz_n);
-	else if (currPositionPtr->tomove == BMOVE ) 
+	else if (currPositionPtr->tomove == BLACK ) 
 		return  movgen_black(index0,anz_s,anz_n);
     else
         abort();
