@@ -17,7 +17,6 @@
  */
 
 #include "gnome_chess.h"
-#include "portab.h"
 #include "position.h"
 #include "makros.h"
 
@@ -47,7 +46,7 @@ position* gnomechess_position_copy(position *pos ) {
 
 	cpPos = gnomechess_position_new();
 	memcpy(cpPos, pos, sizeof(position));
-	memcpy(cpPos->square, pos->square, sizeof(BYTE)*120);
+	memcpy(cpPos->square, pos->square, sizeof(gchar)*120);
 	return cpPos;
 }
 
@@ -75,7 +74,7 @@ static void gnomechess_position_set_empty(position *pos) {
      pos->sta = 0;
      pos->vf = EMPTY;
 
-     pos->tomove = NMOVE;  
+     pos->tomove = NONE;  
 
 }
 
@@ -120,35 +119,42 @@ void gnomechess_position_set_initial(position *pos) {
 	pos->sth = 0;
 	pos->ski = E8;
 	pos->vf = EMPTY;
-	pos->tomove = WMOVE;
+	pos->tomove = WHITE;
 }
 
-static void gnomechess_position_wcastle_short(position *pos) {
+/* 
+ * Move Functions
+ *
+ * A set of functions to make a move in the context of the position 
+ * passed in.
+ *
+ */
+static void gnomechess_position_move_white_castle_short(position *pos) {
         pos->square[E1] = pos->square[H1] = EMPTY;
         pos->square[F1] = WR;
         pos->square[G1] = WK;
 }
 
-static void gnomechess_position_wcastle_long(position *pos) {
+static void gnomechess_position_move_white_castle_long(position *pos) {
         pos->square[E1] = pos->square[A1] = EMPTY;
         pos->square[C1] = WK;
         pos->square[D1] = WR;
 }
 
-static void gnomechess_position_bcastle_short(position *pos) {
+static void gnomechess_position_move_black_castle_short(position *pos) {
         pos->square[E8] = pos->square[H8] = EMPTY;
         pos->square[F8] = BR;
         pos->square[G8] = BK;
 }
 
-static void gnomechess_position_bcastle_long(position *pos) {
+static void gnomechess_position_move_black_castle_long(position *pos) {
         pos->square[E8] = pos->square[A8] = EMPTY;
         pos->square[C8] = BK;
         pos->square[D8] = BR;
 }
 
-static void gnomechess_position_white_move(position *pos, int from, int to) {
-	WORD piece,zfeld;
+static void gnomechess_position_move_white(position *pos, int from, int to) {
+	gshort piece,zfeld;
 
 	piece = pos->square[from];
 
@@ -207,10 +213,10 @@ static void gnomechess_position_white_move(position *pos, int from, int to) {
 			/*  If we are castling */
 			switch  (to) {
 				case G1 :
-					gnomechess_position_wcastle_short(pos);
+					gnomechess_position_move_white_castle_short(pos);
 					break;  
 				case C1 :
-					gnomechess_position_wcastle_long(pos);
+					gnomechess_position_move_white_castle_long(pos);
 					break;  
 				default :       
 					abort();
@@ -230,8 +236,8 @@ static void gnomechess_position_white_move(position *pos, int from, int to) {
 	}
 }
 
-static void gnomechess_position_black_move(position *pos, int from, int to) {
-	WORD piece,zfeld;
+static void gnomechess_position_move_black(position *pos, int from, int to) {
+	gshort piece,zfeld;
 
 	piece = pos->square[from];
 
@@ -289,10 +295,10 @@ static void gnomechess_position_black_move(position *pos, int from, int to) {
 			/*  If we are castling */
 			switch  (to)    {
 				case G8 :       
-					gnomechess_position_bcastle_short(pos);
+					gnomechess_position_move_black_castle_short(pos);
 					break; 
 				case C8 :
-					gnomechess_position_bcastle_long(pos);
+					gnomechess_position_move_black_castle_long(pos);
 					break; 
 				default :
 					abort();
@@ -312,22 +318,29 @@ static void gnomechess_position_black_move(position *pos, int from, int to) {
 	}
 }
 
-void gnomechess_position_make_move(position *pos, int from, int to) {
+void gnomechess_position_move(position *pos, int from, int to) {
 
 	switch (currPositionPtr->tomove) {
-		case WMOVE:
-			gnomechess_position_white_move(pos, from,to);
-			pos->tomove = BMOVE;
+		case WHITE:
+			gnomechess_position_move_white(pos, from,to);
+			pos->tomove = BLACK;
 			break;
-		case BMOVE:
-			gnomechess_position_black_move(pos, from,to);
-			pos->tomove = WMOVE;
+		case BLACK:
+			gnomechess_position_move_black(pos, from,to);
+			pos->tomove = WHITE;
 			break;
         	default :
 			abort();
 	}
 }
 
+/* 
+ * Move Reverse Functions
+ *
+ * A set of functions to reverse a previous move in the context of the position 
+ * passed in.
+ *
+ */
 static void gnomechess_position_move_reverse_castling_white_short(position *pos) {
         pos->square[E1]=WK;
         pos->square[F1]=pos->square[G1]=EMPTY;
@@ -365,7 +378,7 @@ static void gnomechess_position_move_reverse_promotion_black(position *pos, int
 void gnomechess_position_move_reverse_white(position *pos, int from, int to) {
    int fi;
 
-   pos->tomove = WMOVE;     /*      change tomove      */
+   pos->tomove = WHITE;     /*      change tomove      */
 
    if (to & 128) {        /*    Promotion     */
       gnomechess_position_move_reverse_promotion_white(pos,from,to);
@@ -423,7 +436,7 @@ void gnomechess_position_move_reverse_white(position *pos, int from, int to) {
 void gnomechess_position_move_reverse_black(position *pos, int from, int to) {
 	int fi;
 
-	pos->tomove = BMOVE;      /* change tomove */
+	pos->tomove = BLACK;      /* change tomove */
 
 	if (to & 128) {        /*    Promotion  */
 		gnomechess_position_move_reverse_promotion_black(pos,from,to);
@@ -480,10 +493,10 @@ void gnomechess_position_move_reverse_black(position *pos, int from, int to) {
 void gnomechess_position_move_reverse(position *pos, int from, int to) {
 
 	switch (currPositionPtr->tomove) {
-		case WMOVE:
+		case WHITE:
 			gnomechess_position_move_reverse_black(pos, from,to);
 			break;
-		case BMOVE:
+		case BLACK:
 			gnomechess_position_move_reverse_white(pos, from,to);
 			break;
         	default :
